==> igniteui-react-charts-16.4.1.tgz: package/ES2015/HorizontalAnchoredCategorySeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { AnchoredCategorySeries } from "./AnchoredCategorySeries";
import { IHorizontalAnchoredCategorySeriesInteractionManager_$type } from "./IHorizontalAnchoredCategorySeriesInteractionManager";
import { DVContainer } from "igniteui-react-core/ES2015/DVContainer";
import { Type, runOn, Point_$type, typeCast, EnumUtil, enumGetBox, markType } from "igniteui-react-core/ES2015/type";
import { CategoryAxisBase } from "./CategoryAxisBase";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { NumericYAxis } from "./NumericYAxis";
import { CategoryMode_$type } from "./CategoryMode";
import { Rect } from "igniteui-react-core/ES2015/Rect";
import { ScalerParams } from "./ScalerParams";
import { Axis } from "./Axis";
import { TrendLineType_$type } from "igniteui-react-core/ES2015/TrendLineType";
import { CategoryTrendLineManagerFactory } from "./CategoryTrendLineManagerFactory";
import { ISortingAxis_$type } from "./ISortingAxis";
import { CategoryXAxis } from "./CategoryXAxis";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
export class HorizontalAnchoredCategorySeries extends AnchoredCategorySeries {
    constructor() {
        super(...arguments);
        this.ps = null;
        this.po = null;
        this.pu = null;
        this.pq = 0;
    }
    get pt() {
        if (this.ps == null) {
            this.ps = DVContainer.instance.createInstance(IHorizontalAnchoredCategorySeriesInteractionManager_$type, () => this.b2.n);
        }
        return this.ps;
    }
    hm() {
        super.hm();
        this.xAxis = null;
        this.yAxis = null;
    }
    bd() {
        if (this.be == 0) {
            return 1;
        }
        else {
            return super.bd();
        }
    }
    mx() {
        return this.po;
    }
    nh() {
        return this.pu;
    }
    ln(a) {
        if (this.my == null || this.my.m.count == 0 || !this.hasMarkers || !this.lu()) {
            return Rect.empty;
        }
        return this.pt.d$d(this, this.my.m, a, runOn(this, this.p6));
    }
    p6(a) {
        return this.oo.c3(a);
    }
    py(a, b, c) {
        return this.pt.d$c(this, this.nh(), a, b, c);
    }
    ah(a) {
        return this.pt.d$a(this, this.my.f, this.ny(this.bi), this.nz(this.bi), a);
    }
    ai(a) {
        return this.pt.d$b(this, this.my.f, this.ny(this.bi), this.nz(this.bi), a);
    }
    df(a, b) {
        if (this.de(a, b)) {
            return true;
        }
        if (this.lv(a, b)) {
            return true;
        }
        return false;
    }
    getOffsetValue() {
        return this.m2.r(this.mx(), this.bi.bq, this.bi.bp, this.getEffectiveViewport1(this.bi));
    }
    getCategoryWidth() {
        let a = this.getEffectiveViewport1(this.bi);
        return this.mx().getCategorySize(this.bi.bq, this.bi.bp, a);
    }
    ej(a, b, c) {
        if (this.bs == null) {
            return NaN;
        }
        let d = this.getEffectiveViewport1(this.bi);
        let e = this.mx();
        let f = new ScalerParams(0, this.bs.ml, this.bi.bp, e.b8, d);
        let g = this.m2.r(e, this.bs.ml, this.bi.bp, d);
        return this.el(this.valueColumn, a, e, f, g, runOn(this, this.nw), b, c);
    }
    fa(a, b) {
        return this.fb(a, b, this.mx(), runOn(this, this.nw), this.valueColumn);
    }
    e8(a, b) {
        return this.e9(a, b, this.mx(), runOn(this, this.nw), this.valueColumn);
    }
    d5(a, b, c, d, e) {
        if (this.valueColumn == null) {
            return Number.POSITIVE_INFINITY;
        }
        return this.d6(a, b, this.mx(), d, e, this.valueColumn.count, runOn(this, this.nw));
    }
    lc(a, b, c) {
        if (this.mx() == null || this.nh() == null) {
            return { $type: Point_$type, x: NaN, y: NaN };
        }
        return this.le(a, b, c, this.m2.r(this.mx(), this.bi.bq, this.bi.bp, this.getEffectiveViewport1(this.bi)), this.nh(), this.mx(), null, null, null);
    }
    fetchXAxis() {
        return this.po;
    }
    fetchYAxis() {
        return this.pu;
    }
    o6(a) {
        this.xAxis = typeCast(CategoryAxisBase.$, a);
    }
    o7(a) {
        this.yAxis = typeCast(NumericYAxis.$, a);
    }
    ns() {
        return this.pu != null && this.pu.ck();
    }
    p2(a) {
        this.po = a;
    }
    p3(a) {
        this.pu = a;
    }
    mr(a, b) {
        return this.ol(a, b, this.po);
    }
    ir(a, b, c, d) {
        switch (b) {
            case HorizontalAnchoredCategorySeries.$$p[0]:
                this.p2(this.xAxis);
                if (this.oo.cx) {
                    this.oo.cw = CategoryTrendLineManagerFactory.a(this.oo.cw, this.po, this.jo, this, this.b2);
                }
                break;
            case "TrendLineType":
                let e = EnumUtil.getEnumValue(TrendLineType_$type, d);
                if (e != 0) {
                    this.oo.cw = CategoryTrendLineManagerFactory.a(this.oo.cw, this.po, this.jo, this, this.b2);
                }
                break;
        }
        super.ir(a, b, c, d);
        switch (b) {
            case HorizontalAnchoredCategorySeries.$$p[0]:
                if (c != d) {
                    this.hs(typeCast(Axis.$, c));
                    this.iw(typeCast(Axis.$, d));
                    this.p2(this.xAxis);
                    this.m6.cl.g(this.eq);
                    this.i4(false);
                    this.ib();
                }
                break;
            case HorizontalAnchoredCategorySeries.$$p[1]:
                if (c != d) {
                    this.hs(typeCast(Axis.$, c));
                    this.iw(typeCast(Axis.$, d));
                    this.p3(this.yAxis);
                    this.m6.cl.g(this.eq);
                    this.ns();
                    this.i4(false);
                    this.ib();
                }
                break;
            case "CategoryMode":
                if (this.xAxis != null) {
                    this.xAxis.kg(true);
                }
                break;
        }
    }
    hr(a, b, c, d) {
        super.hr(a, b, c, d);
        if (this.po != null && typeCast(ISortingAxis_$type, this.po) !== null) {
            this.po.i$i();
        }
        switch (a) {
            case 4:
                if (this.po != null) {
                    this.po.ck();
                }
                if (this.pu != null && !this.pu.ck()) {
                    this.i4(true);
                }
                break;
            case 1:
                if (this.po != null) {
                    this.po.ck();
                }
                if (this.pu != null && !this.pu.ck()) {
                    this.i4(true);
                }
                break;
            case 0:
                if (this.po != null) {
                    this.po.ck();
                }
                if (this.pu != null && !this.pu.ck()) {
                    this.i4(true);
                }
                break;
            case 2:
                if (this.oz != null && this.oo.cl.d > 0 && this.pu != null && !this.pu.ck()) {
                    this.i4(true);
                }
                break;
            case 3:
                if (d == this.oz) {
                    if (this.po != null) {
                        this.po.ck();
                    }
                    if (this.pu != null && !this.pu.ck()) {
                        this.i4(true);
                    }
                }
                break;
        }
    }
    pw(a) {
        if (typeCast(CategoryXAxis.$, a) !== null || a.b5) {
            return true;
        }
        return false;
    }
    px(a) {
        if (typeCast(NumericYAxis.$, a) !== null) {
            return true;
        }
        return false;
    }
    get pr() {
        return this.pq;
    }
    set pr(a) {
        let b = this.pr;
        if (a != b) {
            this.pq = a;
            this.raisePropertyChanged("CategoryMode", enumGetBox(CategoryMode_$type, b), enumGetBox(CategoryMode_$type, this.pr));
        }
    }
    get useHighMarkerFidelity() {
        return this.nt;
    }
}
HorizontalAnchoredCategorySeries.$t = markType(HorizontalAnchoredCategorySeries, 'HorizontalAnchoredCategorySeries', AnchoredCategorySeries.$);
Type.dep(DependencyProperty, PropertyMetadata, HorizontalAnchoredCategorySeries, 'raisePropertyChanged', ['XAxis::p4', [CategoryAxisBase.$, null], 'YAxis::p5', [NumericYAxis.$, null]]);
/*<BeginStatics Name="Infragistics.Controls.Charts.HorizontalAnchoredCategorySeries" />*/
/*<EndStatics Name="Infragistics.Controls.Charts.HorizontalAnchoredCategorySeries" />*/

==> igniteui-react-charts-16.6.4.tgz: package/ES2015/HorizontalAnchoredCategorySeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { AnchoredCategorySeries } from "./AnchoredCategorySeries";
import { IHorizontalAnchoredCategorySeriesInteractionManager_$type } from "./IHorizontalAnchoredCategorySeriesInteractionManager";
import { DVContainer } from "igniteui-react-core/ES2015/DVContainer";
import { Type, runOn, Point_$type, typeCast, EnumUtil, enumGetBox, markType } from "igniteui-react-core/ES2015/type";
import { CategoryAxisBase } from "./CategoryAxisBase";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { NumericYAxis } from "./NumericYAxis";
import { CategoryMode_$type } from "./CategoryMode";
import { Rect } from "igniteui-react-core/ES2015/Rect";
import { ScalerParams } from "./ScalerParams";
import { Axis } from "./Axis";
import { TrendLineType_$type } from "igniteui-react-core/ES2015/TrendLineType";
import { CategoryTrendLineManagerFactory } from "./CategoryTrendLineManagerFactory";
import { ISortingAxis_$type } from "./ISortingAxis";
import { CategoryXAxis } from "./CategoryXAxis";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
export class HorizontalAnchoredCategorySeries extends AnchoredCategorySeries {
    constructor() {
        super(...arguments);
        this.pt = null;
        this.pp = null;
        this.pv = null;
        this.pr = 0;
    }
    get pu() {
        if (this.pt == null) {
            this.pt = DVContainer.instance.createInstance(IHorizontalAnchoredCategorySeriesInteractionManager_$type, () => this.b2.n);
        }
        return this.pt;
    }
    hm() {
        super.hm();
        this.xAxis = null;
        this.yAxis = null;
    }
    bd() {
        if (this.be == 0) {
            return 1;
        }
        else {
            return super.bd();
        }
    }
    mx() {
        return this.pp;
    }
    nh() {
        return this.pv;
    }
    ln(a) {
        if (this.my == null || this.my.m.count == 0 || !this.hasMarkers || !this.lu()) {
            return Rect.empty;
        }
        return this.pu.d$d(this, this.my.m, a, runOn(this, this.p7));
    }
    p7(a) {
        return this.op.c5(a);
    }
    pz(a, b, c) {
        return this.pu.d$c(this, this.nh(), a, b, c);
    }
    ah(a) {
        return this.pu.d$a(this, this.my.f, this.ny(this.bi), this.nz(this.bi), a);
    }
    ai(a) {
        return this.pu.d$b(this, this.my.f, this.ny(this.bi), this.nz(this.bi), a);
    }
    df(a, b) {
        if (this.de(a, b)) {
            return true;
        }
        if (this.lv(a, b)) {
            return true;
        }
        return false;
    }
    getOffsetValue() {
        return this.m2.r(this.mx(), this.bi.bs, this.bi.br, this.getEffectiveViewport1(this.bi));
    }
    getCategoryWidth() {
        let a = this.getEffectiveViewport1(this.bi);
        return this.mx().getCategorySize(this.bi.bs, this.bi.br, a);
    }
    ej(a, b, c) {
        if (this.bs == null) {
            return NaN;
        }
        let d = this.getEffectiveViewport1(this.bi);
        let e = this.mx();
        let f = new ScalerParams(0, this.bs.mn, this.bi.br, e.b8, d);
        let g = this.m2.r(e, this.bs.mn, this.bi.br, d);
        return this.el(this.valueColumn, a, e, f, g, runOn(this, this.nw), b, c);
    }
    fa(a, b) {
        return this.fb(a, b, this.mx(), runOn(this, this.nw), this.valueColumn);
    }
    e8(a, b) {
        return this.e9(a, b, this.mx(), runOn(this, this.nw), this.valueColumn);
    }
    d5(a, b, c, d, e) {
        if (this.valueColumn == null) {
            return Number.POSITIVE_INFINITY;
        }
        return this.d6(a, b, this.mx(), d, e, this.valueColumn.count, runOn(this, this.nw));
    }
    lc(a, b, c) {
        if (this.mx() == null || this.nh() == null) {
            return { $type: Point_$type, x: NaN, y: NaN };
        }
        return this.le(a, b, c, this.m2.r(this.mx(), this.bi.bs, this.bi.br, this.getEffectiveViewport1(this.bi)), this.nh(), this.mx(), null, null, null);
    }
    fetchXAxis() {
        return this.pp;
    }
    fetchYAxis() {
        return this.pv;
    }
    o7(a) {
        this.xAxis = typeCast(CategoryAxisBase.$, a);
    }
    o8(a) {
        this.yAxis = typeCast(NumericYAxis.$, a);
    }
    ns() {
        return this.pv != null && this.pv.ck();
    }
    p3(a) {
        this.pp = a;
    }
    p4(a) {
        this.pv = a;
    }
    mr(a, b) {
        return this.om(a, b, this.pp);
    }
    ir(a, b, c, d) {
        switch (b) {
            case HorizontalAnchoredCategorySeries.$$p[0]:
                this.p3(this.xAxis);
                if (this.op.cz) {
                    this.op.cy = CategoryTrendLineManagerFactory.a(this.op.cy, this.pp, this.jo, this, this.b2);
                }
                break;
            case "TrendLineType":
                let e = EnumUtil.getEnumValue(TrendLineType_$type, d);
                if (e != 0) {
                    this.op.cy = CategoryTrendLineManagerFactory.a(this.op.cy, this.pp, this.jo, this, this.b2);
                }
                break;
        }
        super.ir(a, b, c, d);
        switch (b) {
            case HorizontalAnchoredCategorySeries.$$p[0]:
                if (c != d) {
                    this.hs(typeCast(Axis.$, c));
                    this.iw(typeCast(Axis.$, d));
                    this.p3(this.xAxis);
                    this.m6.cn.g(this.eq);
                    this.i4(false);
                    this.ib();
                }
                break;
            case HorizontalAnchoredCategorySeries.$$p[1]:
                if (c != d) {
                    this.hs(typeCast(Axis.$, c));
                    this.iw(typeCast(Axis.$, d));
                    this.p4(this.yAxis);
                    this.m6.cn.g(this.eq);
                    this.ns();
                    this.i4(false);
                    this.ib();
                }
                break;
            case "CategoryMode":
                if (this.xAxis != null) {
                    this.xAxis.kg(true);
                }
                break;
        }
    }
    hr(a, b, c, d) {
        super.hr(a, b, c, d);
        if (this.pp != null && typeCast(ISortingAxis_$type, this.pp) !== null) {
            this.pp.i$i();
        }
        switch (a) {
            case 4:
                if (this.pp != null) {
                    this.pp.ck();
                }
                if (this.pv != null && !this.pv.ck()) {
                    this.i4(true);
                }
                break;
            case 1:
                if (this.pp != null) {
                    this.pp.ck();
                }
                if (this.pv != null && !this.pv.ck()) {
                    this.i4(true);
                }
                break;
            case 0:
                if (this.pp != null) {
                    this.pp.ck();
                }
                if (this.pv != null && !this.pv.ck()) {
                    this.i4(true);
                }
                break;
            case 2:
                if (this.o0 != null && this.op.cn.d > 0 && this.pv != null && !this.pv.ck()) {
                    this.i4(true);
                }
                break;
            case 3:
                if (d == this.o0) {
                    if (this.pp != null) {
                        this.pp.ck();
                    }
                    if (this.pv != null && !this.pv.ck()) {
                        this.i4(true);
                    }
                }
                break;
        }
    }
    px(a) {
        if (typeCast(CategoryXAxis.$, a) !== null || a.b5) {
            return true;
        }
        return false;
    }
    py(a) {
        if (typeCast(NumericYAxis.$, a) !== null) {
            return true;
        }
        return false;
    }
    get ps() {
        return this.pr;
    }
    set ps(a) {
        let b = this.ps;
        if (a != b) {
            this.pr = a;
            this.raisePropertyChanged("CategoryMode", enumGetBox(CategoryMode_$type, b), enumGetBox(CategoryMode_$type, this.ps));
        }
    }
    get useHighMarkerFidelity() {
        return this.nt;
    }
}
HorizontalAnchoredCategorySeries.$t = markType(HorizontalAnchoredCategorySeries, 'HorizontalAnchoredCategorySeries', AnchoredCategorySeries.$);
Type.dep(DependencyProperty, PropertyMetadata, HorizontalAnchoredCategorySeries, 'raisePropertyChanged', ['XAxis::p5', [CategoryAxisBase.$, null], 'YAxis::p6', [NumericYAxis.$, null]]);
